<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Mostviewed Export Entity by Amasty
 */

namespace Amasty\MostviewedExportEntity\Export\DataHandling\FieldModifier\Customer;

use Amasty\ExportCore\Api\FieldModifier\FieldModifierInterface;
use Amasty\ExportCore\Export\DataHandling\AbstractModifier;
use Amasty\ExportCore\Export\DataHandling\ModifierProvider;
use Amasty\ExportCore\Export\SourceOption\CustomerGroupOptions;

class GroupId2GroupCode extends AbstractModifier implements FieldModifierInterface
{
    /**
     * @var CustomerGroupOptions
     */
    private $sourceModel;

    /**
     * @var array|null
     */
    private $map;

    public function __construct(
        $config,
        CustomerGroupOptions $sourceModel
    ) {
        parent::__construct($config);
        $this->sourceModel = $sourceModel;
    }

    public function getLabel(): string
    {
        return __('Convert Group Id To Group Code')->getText();
    }

    public function transform($value)
    {
        $map = $this->getMap();

        return $map[$value] ?? $value;
    }

    public function getGroup(): string
    {
        return ModifierProvider::CUSTOM_GROUP;
    }

    private function getMap()
    {
        if (!$this->map) {
            $this->map = [];

            $options = $this->sourceModel->toOptionArray();
            foreach ($options as $option) {
                $this->map[$option['value']] = $option['label'];
            }
        }

        return $this->map;
    }
}
